@@ -89,6 +89,9 @@ FAILEDOPERATION_JSONMARSHALERROR = 'FailedOperation.JsonMarshalError'
 # json反序列化失败。
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
+# 返回数据量过大，请缩减数据查询范围
+FAILEDOPERATION_LOGCONTENTOVERLIMIT = 'FailedOperation.LogContentOverLimit'
+
 # 检查到改动前后策略一致，无改动点。
 FAILEDOPERATION_NOTCHANGESTRATEGY = 'FailedOperation.NotChangeStrategy'
 
@@ -194,7 +197,7 @@ INTERNALERROR_DBERROR = 'InternalError.DBError'
 # 数据库操作失败。
 INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'
 
-# 数据库记录不存在。
+# 数据库实例不存在。
 INTERNALERROR_DBRECORDNOTEXISTERROR = 'InternalError.DBRecordNotExistError'
 
 # 数据库内部错误。
@@ -572,6 +575,9 @@ RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
 # 认证失败，没有足够权限。
 UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPrivileges'
 
