@@ -272,6 +272,9 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCESTATE = 'InvalidParameterValue.InvalidInsta
 # 无效的IPv6地址。
 INVALIDPARAMETERVALUE_INVALIDIPV6 = 'InvalidParameterValue.InvalidIpv6'
 
+# 旧的带宽值无效。
+INVALIDPARAMETERVALUE_INVALIDOLDBANDWIDTH = 'InvalidParameterValue.InvalidOldBandwidth'
+
 # 该Tag不合法。
 INVALIDPARAMETERVALUE_INVALIDTAG = 'InvalidParameterValue.InvalidTag'
 
@@ -632,6 +635,9 @@ LIMITEXCEEDED_VPCPEERTOTALLIMITEXCEEDED = 'LimitExceeded.VpcPeerTotalLimitExceed
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 缺少多个参数错误
+MISSINGPARAMETER_MULTIMISSINGPARAMETER = 'MissingParameter.MultiMissingParameter'
+
 # 指定公网IP处于隔离状态。
 OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
 
@@ -743,6 +749,9 @@ UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.Band
 # 已绑定EIP。
 UNSUPPORTEDOPERATION_BINDEIP = 'UnsupportedOperation.BindEIP'
 
+# 添加 community 时，传播条件只支持 vpg 类型或 vpg 实例
+UNSUPPORTEDOPERATION_BROADCASTCONDITIONMUSTBEVPGTYPEORVPGINSTANCE = 'UnsupportedOperation.BroadcastConditionMustBeVpgTypeOrVpgInstance'
+
 # 指定VPC CIDR范围不支持私有网络和基础网络设备互通。
 UNSUPPORTEDOPERATION_CIDRUNSUPPORTEDCLASSICLINK = 'UnsupportedOperation.CIDRUnSupportedClassicLink'
 
@@ -767,6 +776,9 @@ UNSUPPORTEDOPERATION_CCNNOTATTACHED = 'UnsupportedOperation.CcnNotAttached'
 # 当前云联网未开启路由传播策略。
 UNSUPPORTEDOPERATION_CCNNOTENABLEBROADCASTPOLICY = 'UnsupportedOperation.CcnNotEnableBroadcastPolicy'
 
+# 添加 community 时，vpg 需要开通传播 community 白名单
+UNSUPPORTEDOPERATION_CCNNOTENABLECOMMUNITY = 'UnsupportedOperation.CcnNotEnableCommunity'
+
 # 跨账号场景下不支持自驾云账号实例 关联普通账号云联网。
 UNSUPPORTEDOPERATION_CCNORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.CcnOrdinaryAccountRefuseAttach'
 
@@ -917,6 +929,9 @@ UNSUPPORTEDOPERATION_ISNOTFINANCEACCOUNT = 'UnsupportedOperation.IsNotFinanceAcc
 # 该ISP不支持此操作。
 UNSUPPORTEDOPERATION_ISPNOTSUPPORTED = 'UnsupportedOperation.IspNotSupported'
 
+# 需要先解绑 IDC通道
+UNSUPPORTEDOPERATION_LDCXDISASSOCIATE = 'UnsupportedOperation.LDCXDisassociate'
+
 # 指定的CDC已存在本地网关。
 UNSUPPORTEDOPERATION_LOCALGATEWAYALREADYEXISTS = 'UnsupportedOperation.LocalGatewayAlreadyExists'
 
